@@ -15,7 +15,7 @@ except ImportError:
 from localstack import config
 from localstack.utils import bootstrap
 from localstack.utils.common import (
-    CaptureOutput, FuncThread, TMP_FILES, short_uid, save_file, rm_rf,
+    CaptureOutput, FuncThread, TMP_FILES, short_uid, save_file, rm_rf, in_docker,
     to_str, run, cp_r, json_safe, get_free_tcp_port)
 from localstack.services.install import INSTALL_PATH_LOCALSTACK_FAT_JAR
 from localstack.utils.aws.dead_letter_queue import lambda_error_to_dead_letter_queue, sqs_error_to_dead_letter_queue
@@ -91,15 +91,17 @@ def _store_logs(func_details, log_output, invocation_time=None, container_id=Non
     return store_cloudwatch_logs(log_group_name, log_stream_name, log_output, invocation_time)
 
 
-def get_docker_host_from_container():
+def get_main_endpoint_from_container():
     global DOCKER_MAIN_CONTAINER_IP
     if DOCKER_MAIN_CONTAINER_IP is None:
+        DOCKER_MAIN_CONTAINER_IP = False
         try:
-            DOCKER_MAIN_CONTAINER_IP = bootstrap.get_main_container_ip()
+            if in_docker():
+                DOCKER_MAIN_CONTAINER_IP = bootstrap.get_main_container_ip()
+                LOG.info('Determined main container target IP: %s' % DOCKER_MAIN_CONTAINER_IP)
         except Exception as e:
             LOG.info('Unable to get IP address of main Docker container "%s": %s' %
                 (bootstrap.MAIN_CONTAINER_NAME, e))
-            DOCKER_MAIN_CONTAINER_IP = False
     # return main container IP, or fall back to Docker host (bridge IP, or host DNS address)
     return DOCKER_MAIN_CONTAINER_IP or config.DOCKER_HOST_FROM_CONTAINER
 
@@ -235,10 +237,9 @@ class LambdaExecutorContainers(LambdaExecutor):
         event_body = json.dumps(json_safe(event))
         stdin = self.prepare_event(environment, event_body)
 
-        docker_host = get_docker_host_from_container()
+        main_endpoint = get_main_endpoint_from_container()
 
-        environment['HOSTNAME'] = docker_host
-        environment['LOCALSTACK_HOSTNAME'] = docker_host
+        environment['LOCALSTACK_HOSTNAME'] = main_endpoint
         environment['_HANDLER'] = handler
         if os.environ.get('HTTP_PROXY'):
             environment['HTTP_PROXY'] = os.environ['HTTP_PROXY']
@@ -783,13 +784,15 @@ class Util:
         """
         entries = ['.']
         base_dir = os.path.dirname(archive)
-        for pattern in ['%s/*.jar', '%s/lib/*.jar', '%s/*.zip']:
+        for pattern in ['%s/*.jar', '%s/lib/*.jar', '%s/java/lib/*.jar', '%s/*.zip']:
             for entry in glob.glob(pattern % base_dir):
                 if os.path.realpath(archive) != os.path.realpath(entry):
                     entries.append(os.path.relpath(entry, base_dir))
         # make sure to append the localstack-utils.jar at the end of the classpath
         # https://github.com/localstack/localstack/issues/1160
         entries.append(os.path.relpath(archive, base_dir))
+        entries.append('*.jar')
+        entries.append('java/lib/*.jar')
         result = ':'.join(entries)
         return result
 
